==> afnix_2.5.1.orig.tar.gz: afnix-src-2.5.1/src/srv/tls/shl/TlsServer.hpp <==
// ---------------------------------------------------------------------------
// - TlsServer.hpp                                                           -
// - afnix:tls service - tls server class definition                         -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2015 amaury darsch                                   -
// ---------------------------------------------------------------------------

#ifndef  AFNIX_TLSSERVER_HPP
#define  AFNIX_TLSSERVER_HPP

#ifndef  AFNIX_TCPSERVER_HPP
#include "TcpServer.hpp"
#endif

#ifndef  AFNIX_TLSSOCKET_HPP
#include "TlsSocket.hpp"
#endif

namespace afnix {

  /// The TlsServer class is the server socket class for the tls protocol.
  /// The class is a wrapper around the tcp server with extra information
  /// needed to setup a secure channel. Once a connection is accepted (in
  /// the tcp sense) the handshake can start.
  /// @author amaury darsch

  class TlsServer : public TcpServer {
  public:
    /// create a tls server on a ephemeral port
    TlsServer (void);

    /// create a tls server with a host and port
    /// @param host the host to bind the server
    /// @param port the port to listen
    TlsServer (const String& host, t_word port);

    /// @return the class name
    String repr (void) const;
    
    /// @return an accepted connected tcp socket
    TcpSocket* accept (void) const;

  private:
    // make the copy constructor private
    TlsServer (const TlsServer&);
    // make the assignment operator private
    TlsServer& operator = (const TlsServer&);

  public:
    /// create a new object in a generic way
    /// @param argv the argument vector
    static Object* mknew (Vector* argv);
  };
}

#endif

==> afnix_2.6.3.orig.tar.gz: afnix-src-2.6.3/src/srv/tls/shl/TlsServer.hpp <==
// ---------------------------------------------------------------------------
// - TlsServer.hpp                                                           -
// - afnix:tls service - tls server class definition                         -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2016 amaury darsch                                   -
// ---------------------------------------------------------------------------

#ifndef  AFNIX_TLSSERVER_HPP
#define  AFNIX_TLSSERVER_HPP

#ifndef  AFNIX_TCPSERVER_HPP
#include "TcpServer.hpp"
#endif

#ifndef  AFNIX_TLSSOCKET_HPP
#include "TlsSocket.hpp"
#endif

namespace afnix {

  /// The TlsServer class is the server socket class for the tls protocol.
  /// The class is a wrapper around the tcp server with extra information
  /// needed to setup a secure channel. Once a connection is accepted (in
  /// the tcp sense) the handshake can start.
  /// @author amaury darsch

  class TlsServer : public TcpServer {
  protected:
    /// the tls parameters
    TlsParams d_prms;
    
  public:
    /// create a tls server on a ephemeral port
    TlsServer (void);

    /// create a tls server with a host and port
    /// @param host the host to bind the server
    /// @param port the port to listen
    TlsServer (const String& host, t_word port);

    /// create a tls server with a host, port and parameters
    /// @param host the host to bind the server
    /// @param port the port to listen
    /// @param prms the tls parameters
    TlsServer (const String& host, t_word port, const TlsParams& prms);
    
    /// @return the class name
    String repr (void) const;
    
    /// @return an accepted connected tcp socket
    TcpSocket* accept (void) const;

    /// set the tls parameters
    /// @param prms the tls parameters
    virtual void setprms (const TlsParams& prms);
    
  private:
    // make the copy constructor private
    TlsServer (const TlsServer&);
    // make the assignment operator private
    TlsServer& operator = (const TlsServer&);

  public:
    /// create a new object in a generic way
    /// @param argv the argument vector
    static Object* mknew (Vector* argv);

    /// @return true if the given quark is defined
    bool isquark (const long quark, const bool hflg) const;
    
    /// apply this object with a set of arguments and a quark
    /// @param robj  the current runnable
    /// @param nset  the current nameset    
    /// @param quark the quark to apply these arguments
    /// @param argv  the arguments to apply
    Object* apply (Runnable* robj, Nameset* nset, const long quark,
		   Vector* argv);
  };
}

#endif
